/*	$NetBSD$ */

/*-
 * Copyright (C) 2008 The NetBSD Foundation
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* 
 * A driver for various dbCool environmental controllers
 */

#ifndef DBCOOLVAR_H
#define DBCOOLVAR_H

#include <sys/cdefs.h>
__KERNEL_RCSID(0, "$NetBSD$");

#include <dev/i2c/i2cvar.h>

#include <dev/sysmon/sysmonvar.h>
#include "sysmon_envsys.h"

#include <dev/i2c/dbcool_reg.h>

enum dbc_sensor_type {
	DBC_CTL = 0,
	DBC_TEMP,
	DBC_VOLT,
	DBC_FAN
};

#define	DBCFLAG_TEMPOFFSET	0x01
#define	DBCFLAG_NEEDSTART	0x02
#define	DBCFLAG_HAS_MAXDUTY	0x04
#define	DBCFLAG_HAS_PWMMUX	0x08
#define	DBCFLAG_MULTI_VCC	0x10
#define	DBCFLAG_MULTI_VCC2	0x20

struct dbcool_sensor {
	enum dbc_sensor_type type;
	int seq;
	uint8_t	reg;
	const char *desc;
};

struct dbcool_power_control {
	uint8_t mux;
	uint8_t min;
	uint8_t max;
	uint8_t cur;
	uint8_t range;
	const char *desc;
};

struct chip_id {
	uint8_t company;
	uint8_t device;
	uint8_t rev;
	struct dbcool_sensor *table;
	struct dbcool_power_control *power;
	int flags;
	const char *name;
};

struct dbcool_softc {
	struct device *parent;
	i2c_tag_t sc_tag;
	i2c_addr_t sc_addr;
	struct chip_id *sc_chip;
	struct sysmon_envsys *sc_sme;
	envsys_data_t sc_sensor[DBCOOL_MAXSENSORS];
	uint8_t regs[DBCOOL_MAXSENSORS];
};

#endif	/* def DBCOOLVAR_H */
